@@ -87,7 +87,7 @@ class ConfidentialLogger(logging.getLoggerClass()):  # type: ignore
                 exc_info=exc_info,
                 extra=extra,
                 stack_info=stack_info,
-                stacklevel=stacklevel,
+                stacklevel=stacklevel,  # type: ignore
             )
 
 
